@@ -30,6 +30,7 @@
 #include "nautilus-dnd.h"
 
 #include "nautilus-program-choosing.h"
+#include "nautilus-link.h"
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
@@ -68,16 +69,11 @@
 void
 nautilus_drag_init (NautilusDragInfo     *drag_info,
 		    const GtkTargetEntry *drag_types,
-		    int                   drag_type_count, 
-		    GdkBitmap            *stipple)
+		    int                   drag_type_count)
 {
 	drag_info->target_list = gtk_target_list_new (drag_types,
 						   drag_type_count);
 
-	if (stipple != NULL) {
-		drag_info->stipple = g_object_ref (stipple);
-	}
-
 	drag_info->drop_occured = FALSE;
 	drag_info->need_to_destroy = FALSE;
 }
@@ -88,10 +84,6 @@ nautilus_drag_finalize (NautilusDragInfo *drag_info)
 	gtk_target_list_unref (drag_info->target_list);
 	nautilus_drag_destroy_selection_list (drag_info->selection_list);
 
-	if (drag_info->stipple != NULL) {
-		g_object_unref (drag_info->stipple);
-	}
-
 	g_free (drag_info);
 }
 
@@ -294,6 +286,11 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 		if (actions & GDK_ACTION_MOVE) {
 			*action = GDK_ACTION_MOVE;
 		}
+
+		if (target_uri) {
+			gnome_vfs_uri_unref (target_uri);
+		}
+
 		return;
 
 	} else if (eel_str_has_prefix (target_uri_string, NAUTILUS_COMMAND_SPECIFIER)
@@ -731,3 +728,41 @@ nautilus_drag_autoscroll_stop (NautilusDragInfo *drag_info)
 		drag_info->auto_scroll_timeout_id = 0;
 	}
 }
+
+gboolean
+nautilus_drag_selection_includes_special_link (GList *selection_list)
+{
+	GList *node;
+	char *uri, *local_path;
+	gboolean link_in_selection;
+	GnomeVFSFileInfo *info;
+
+	link_in_selection = FALSE;
+
+	for (node = selection_list; node != NULL; node = node->next) {
+		uri = ((NautilusDragSelectionItem *) node->data)->uri;
+
+		/* FIXME bugzilla.gnome.org 43020: This does sync. I/O and works only locally. */
+		local_path = gnome_vfs_get_local_path_from_uri (uri);
+
+		if (local_path) {
+			info = gnome_vfs_file_info_new ();
+			gnome_vfs_get_file_info
+				(local_path, info, 
+				 GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
+				 GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
+			/* assume info is blank on failure */
+			link_in_selection = (nautilus_link_local_is_trash_link (local_path, info) ||
+					     nautilus_link_local_is_home_link (local_path, info) ||
+					     nautilus_link_local_is_volume_link (local_path, info));
+			gnome_vfs_file_info_unref (info);
+			g_free (local_path);
+		}
+		
+		if (link_in_selection) {
+			break;
+		}
+	}
+	
+	return link_in_selection;
+}
