@@ -33,6 +33,11 @@ G_BEGIN_DECLS
 /* Which theme is active */
 #define NAUTILUS_PREFERENCES_THEME				"/desktop/gnome/file_views/icon_theme"
 
+/* Desktop Background options */
+#define NAUTILUS_PREFERENCES_BACKGROUND_SET                     "preferences/background_set" 
+#define NAUTILUS_PREFERENCES_BACKGROUND_COLOR                   "preferences/background_color" 
+#define NAUTILUS_PREFERENCES_BACKGROUND_FILENAME                "preferences/background_filename" 
+
 /* How wide the sidebar is (or how wide it will be when expanded) */
 #define NAUTILUS_PREFERENCES_SIDEBAR_WIDTH  			"preferences/sidebar_width"
 
@@ -46,6 +51,7 @@ G_BEGIN_DECLS
 /* Desktop options */
 #define NAUTILUS_PREFERENCES_SHOW_DESKTOP			"preferences/show_desktop"
 #define NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR                "preferences/desktop_is_home_dir"
+#define NAUTILUS_PREFERENCES_DESKTOP_FONT			"preferences/desktop_font"
 
 /* Display  */
 #define NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES  		"/desktop/gnome/file_views/show_hidden_files"
@@ -59,27 +65,9 @@ G_BEGIN_DECLS
 #define NAUTILUS_PREFERENCES_HOME_URI                 		"preferences/home_uri"
 #define NAUTILUS_PREFERENCES_HIDE_BUILT_IN_BOOKMARKS		"preferences/hide_built_in_bookmarks"
 
-/* Proxy */
-#define NAUTILUS_PREFERENCES_HTTP_USE_PROXY                	"/system/gnome_vfs/use_http_proxy"
-#define NAUTILUS_PREFERENCES_HTTP_PROXY_HOST                 	"/system/gnome_vfs/http_proxy_host"
-#define NAUTILUS_PREFERENCES_HTTP_PROXY_PORT                	"/system/gnome_vfs/http_proxy_port"
-
-/* HTTP Proxy Authentication */
-#define NAUTILUS_PREFERENCES_HTTP_PROXY_USE_AUTH                "/system/gnome_vfs/use_http_proxy_authorization"
-#define NAUTILUS_PREFERENCES_HTTP_PROXY_AUTH_USERNAME      	"/system/gnome_vfs/http_proxy_authorization_user"
-#define NAUTILUS_PREFERENCES_HTTP_USE_AUTH_PASSWORD     	"/system/gnome_vfs/http_proxy_authorization_password"
-
-/* Content fonts */
-#define NAUTILUS_PREFERENCES_DEFAULT_FONT			"preferences/default_font"
-#define NAUTILUS_PREFERENCES_DEFAULT_FONT_SIZE			"preferences/default_font_size"
-
 /* Single/Double click preference  */
 #define NAUTILUS_PREFERENCES_CLICK_POLICY			"preferences/click_policy"
 
-/* Xalf settings */
-#define NAUTILUS_PREFERENCES_XALF_ENABLED			"preferences/xalf/enabled"
-#define NAUTILUS_PREFERENCES_XALF_OPTIONS			"preferences/xalf/options"
-
 /* Activating executable text files */
 #define NAUTILUS_PREFERENCES_EXECUTABLE_TEXT_ACTIVATION		"preferences/executable_text_activation"
 
@@ -112,9 +100,7 @@ enum
 #define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_SORT_ORDER		"icon_view/default_sort_order"
 #define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_USE_TIGHTER_LAYOUT	"icon_view/default_use_tighter_layout"
 #define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL		"icon_view/default_zoom_level"
-#define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL_FONT_SIZE	"icon_view/default_zoom_level_font_size"
 #define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_USE_MANUAL_LAYOUT	"icon_view/default_use_manual_layout"
-#define NAUTILUS_PREFERENCES_ICON_VIEW_FONT				"icon_view/font"
 
 /* The icon view uses 2 variables to store the sort order and
  * whether to use manual layout.  However, the UI for these
@@ -132,8 +118,6 @@ enum
 #define NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_IN_REVERSE_ORDER	"list_view/default_sort_in_reverse_order"
 #define NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_ORDER		"list_view/default_sort_order"
 #define NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL		"list_view/default_zoom_level"
-#define NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL_FONT_SIZE	"list_view/default_zoom_level_font_size"
-#define NAUTILUS_PREFERENCES_LIST_VIEW_FONT				"list_view/font"
 
 /* News panel */
 #define NAUTILUS_PREFERENCES_NEWS_MAX_ITEMS				"news/max_items"
@@ -166,7 +150,6 @@ typedef enum
 #define NAUTILUS_PREFERENCES_SHOW_DIRECTORY_ITEM_COUNTS "preferences/show_directory_item_counts"
 #define NAUTILUS_PREFERENCES_SHOW_IMAGE_FILE_THUMBNAILS	"preferences/show_image_thumbnails"
 #define NAUTILUS_PREFERENCES_IMAGE_FILE_THUMBNAIL_LIMIT	"preferences/thumbnail_limit"
-#define NAUTILUS_PREFERENCES_USE_PUBLIC_METADATA	"preferences/use_public_metadata"
 #define NAUTILUS_PREFERENCES_PREVIEW_SOUND		"preferences/preview_sound"
 
 typedef enum
