@@ -512,12 +512,18 @@ compute_text_rectangle (NautilusIconCanvasItem *item,
 			ArtIRect icon_rectangle)
 {
 	ArtIRect text_rectangle;
+	double pixels_per_unit;
+	double text_width, text_height;
+
+	pixels_per_unit = EEL_CANVAS_ITEM (item)->canvas->pixels_per_unit;
+	text_width = item->details->text_width / pixels_per_unit;
+	text_height = item->details->text_height / pixels_per_unit;
 
 	/* Compute text rectangle. */
-	text_rectangle.x0 = (icon_rectangle.x0 + icon_rectangle.x1) / 2 - item->details->text_width / 2;
-	text_rectangle.y0 = icon_rectangle.y1 + LABEL_OFFSET;
-	text_rectangle.x1 = text_rectangle.x0 + item->details->text_width;
-	text_rectangle.y1 = text_rectangle.y0 + item->details->text_height;
+	text_rectangle.x0 = (icon_rectangle.x0 + icon_rectangle.x1) / 2 - text_width / 2;
+	text_rectangle.y0 = icon_rectangle.y1 + LABEL_OFFSET / pixels_per_unit;
+	text_rectangle.x1 = text_rectangle.x0 + text_width;
+	text_rectangle.y1 = text_rectangle.y0 + text_height;
 
 	return text_rectangle;
 }
@@ -810,7 +816,7 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 	    details->text_width > 0 && details->text_height > 0) {
 		draw_frame (item,
 			    drawable,
-			    container->details->highlight_color_rgba,
+			    GTK_WIDGET_HAS_FOCUS (GTK_WIDGET (container)) ? container->details->highlight_color_rgba : container->details->active_color_rgba,
 			    icon_left + (icon_width - details->text_width) / 2,
 			    icon_bottom,
 			    details->text_width, 
@@ -906,6 +912,7 @@ draw_stretch_handles (NautilusIconCanvasItem *item, GdkDrawable *drawable,
 	GdkGC *gc;
 	char *knob_filename;
 	GdkPixbuf *knob_pixbuf;
+	GdkBitmap *stipple;
 	int knob_width, knob_height;
 	
 	if (!item->details->show_stretch_handles) {
@@ -918,9 +925,12 @@ draw_stretch_handles (NautilusIconCanvasItem *item, GdkDrawable *drawable,
 	knob_pixbuf = gdk_pixbuf_new_from_file (knob_filename, NULL);
 	knob_width = gdk_pixbuf_get_width (knob_pixbuf);
 	knob_height = gdk_pixbuf_get_height (knob_pixbuf);
+
+	stipple = eel_stipple_bitmap_for_screen (
+			gdk_drawable_get_screen (GDK_DRAWABLE (drawable)));
 	
 	/* first draw the box */		
-	gdk_gc_set_stipple (gc, eel_stipple_bitmap ());
+	gdk_gc_set_stipple (gc, stipple);
 	gdk_gc_set_fill (gc, GDK_STIPPLED);
 	gdk_draw_rectangle
 		(drawable, gc, FALSE,
@@ -1268,6 +1278,7 @@ create_label_layout (NautilusIconCanvasItem *item,
 	pango_layout_set_width (layout, floor (nautilus_icon_canvas_item_get_max_text_width (item)) * PANGO_SCALE);
 	pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
 	pango_layout_set_spacing (layout, LABEL_LINE_SPACING);
+	pango_layout_set_wrap (layout, PANGO_WRAP_WORD_CHAR);
 
 	/* Create a font description */
 	if (container->details->font) {
@@ -1635,7 +1646,6 @@ nautilus_icon_canvas_item_get_icon_rectangle (const NautilusIconCanvasItem *item
 	
 	g_return_val_if_fail (NAUTILUS_IS_ICON_CANVAS_ITEM (item), eel_art_drect_empty);
 
-	
 	rectangle.x0 = item->details->x;
 	rectangle.y0 = item->details->y;
 	
@@ -1645,6 +1655,13 @@ nautilus_icon_canvas_item_get_icon_rectangle (const NautilusIconCanvasItem *item
 	rectangle.x1 = rectangle.x0 + (pixbuf == NULL ? 0 : gdk_pixbuf_get_width (pixbuf)) / pixels_per_unit;
 	rectangle.y1 = rectangle.y0 + (pixbuf == NULL ? 0 : gdk_pixbuf_get_height (pixbuf)) / pixels_per_unit;
 
+	eel_canvas_item_i2w (EEL_CANVAS_ITEM (item),
+			     &rectangle.x0,
+			     &rectangle.y0);
+	eel_canvas_item_i2w (EEL_CANVAS_ITEM (item),
+			     &rectangle.x1,
+			     &rectangle.y1);
+
 	return rectangle;
 }
 
