@@ -64,6 +64,7 @@
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
+#include <libnautilus-private/nautilus-emblem-utils.h>
 #include <libnautilus-private/nautilus-link.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-undo-signal-handlers.h>
@@ -142,8 +143,6 @@ static GtkTargetEntry target_table[] = {
 	{ "x-special/gnome-reset-background", 0, TARGET_RESET_BACKGROUND }
 };
 
-#define ERASE_EMBLEM_FILENAME	"erase.png"
-
 #define DIRECTORY_CONTENTS_UPDATE_INTERVAL	200 /* milliseconds */
 #define STANDARD_EMBLEM_HEIGHT			52
 #define EMBLEM_LABEL_SPACING			2
@@ -1678,13 +1677,14 @@ create_basic_page (FMPropertiesWindow *window)
 static void
 create_emblems_page (FMPropertiesWindow *window)
 {
-	NautilusCustomizationData *customization_data;
 	GtkWidget *emblems_table, *button, *scroller;
-	char *emblem_name, *dot_pos;
+	char *emblem_name;
 	GdkPixbuf *pixbuf;
 	char *label;
 	NautilusFile *file;
+	GList *icons, *l;
 
+	
 	file = window->details->target_file;
 
 	/* The emblems wrapped table */
@@ -1696,29 +1696,29 @@ create_emblems_page (FMPropertiesWindow *window)
 
 	gtk_notebook_append_page (window->details->notebook, 
 				  scroller, gtk_label_new (_("Emblems")));
-	
-	/* Use nautilus_customization to make the emblem widgets */
-	customization_data = nautilus_customization_data_new ("emblems", TRUE, TRUE,
-							      NAUTILUS_ICON_SIZE_SMALL, 
-							      NAUTILUS_ICON_SIZE_SMALL);
-	
-	while (nautilus_customization_data_get_next_element_for_display (customization_data,
-									 &emblem_name,
-									 &pixbuf,
-									 &label) == GNOME_VFS_OK) {	
 
-		/* strip the suffix, if any */
-		dot_pos = strrchr(emblem_name, '.');
-		if (dot_pos) {
-			*dot_pos = '\0';
+	icons = nautilus_emblem_list_availible ();
+
+	l = icons;
+	while (l != NULL) {
+		emblem_name = l->data;
+		l = l->next;
+		
+		if (!nautilus_emblem_should_show_in_list (emblem_name)) {
+			continue;
 		}
 		
-		if (strcmp (emblem_name, "erase") == 0) {
-			g_object_unref (pixbuf);
-			g_free (label);
-			g_free (emblem_name);
+		pixbuf = nautilus_icon_factory_get_pixbuf_from_name (emblem_name, NULL,
+								     NAUTILUS_ICON_SIZE_SMALL,
+								     &label);
+
+		if (pixbuf == NULL) {
 			continue;
 		}
+
+		if (label == NULL) {
+			label = nautilus_emblem_get_keyword_from_icon_name (emblem_name);
+		}
 		
 		button = eel_labeled_image_check_button_new (label, pixbuf);
 		eel_labeled_image_set_fixed_image_height (EEL_LABELED_IMAGE (GTK_BIN (button)->child), STANDARD_EMBLEM_HEIGHT);
@@ -1729,7 +1729,7 @@ create_emblems_page (FMPropertiesWindow *window)
 
 		/* Attach parameters and signal handler. */
 		g_object_set_data_full (G_OBJECT (button), "nautilus_property_name",
-					emblem_name, g_free);
+					nautilus_emblem_get_keyword_from_icon_name (emblem_name), g_free);
 				     
 		nautilus_file_ref (file);
 		g_object_set_data_full (G_OBJECT (button), "nautilus_file",
@@ -1748,6 +1748,8 @@ create_emblems_page (FMPropertiesWindow *window)
 
 		gtk_container_add (GTK_CONTAINER (emblems_table), button);
 	}
+	eel_g_list_free_deep (icons);
+	
 	gtk_widget_show_all (emblems_table);
 }
 
@@ -2166,6 +2168,8 @@ create_properties_window (StartupData *startup_data)
 	
   	gtk_container_set_border_width (GTK_CONTAINER (window), GNOME_PAD);
 	gtk_window_set_wmclass (GTK_WINDOW (window), "file_properties", "Nautilus");
+	gtk_window_set_screen (GTK_WINDOW (window),
+			       gtk_widget_get_screen (GTK_WIDGET (startup_data->directory_view)));
 
 	/* Set initial window title */
 	update_properties_window_title (GTK_WINDOW (window), window->details->target_file);
@@ -2369,6 +2373,8 @@ fm_properties_window_present (NautilusFile *original_file, FMDirectoryView *dire
 	/* Look to see if there's already a window for this file. */
 	existing_window = g_hash_table_lookup (windows, original_file);
 	if (existing_window != NULL) {
+		gtk_window_set_screen (existing_window,
+				       gtk_widget_get_screen (GTK_WIDGET (directory_view)));
 		gtk_window_present (existing_window);
 		return;
 	}
